summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorHall Liu <hallliu@google.com>2017-07-24 17:58:55 -0700
committerHall Liu <hallliu@google.com>2017-07-25 17:35:30 +0000
commit25921e8d464cf57c570b4757060daa2b41315044 (patch)
tree78f4c50af800e21f3ae63fae0f27bdcbd595e77f
parentf789bc01803194bcdfe47c8257c5cd141519076a (diff)
downloadandroid_packages_services_Telecomm-25921e8d464cf57c570b4757060daa2b41315044.tar.gz
android_packages_services_Telecomm-25921e8d464cf57c570b4757060daa2b41315044.tar.bz2
android_packages_services_Telecomm-25921e8d464cf57c570b4757060daa2b41315044.zip
Don't unmute when answering a handover connection
We usually unmute the mic when a new call is answered. However, since handovers go through the same code path, they'd get unmuted too. We want to preserve the mute behavior from pre-handover, so add a special case check. Bug: 63795849 Test: manual Change-Id: I7c09252d9541ab41c4bb72e5311e64d3c12b53ba
-rw-r--r--src/com/android/server/telecom/CallAudioManager.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/com/android/server/telecom/CallAudioManager.java b/src/com/android/server/telecom/CallAudioManager.java
index f778e302..5f56fcfe 100644
--- a/src/com/android/server/telecom/CallAudioManager.java
+++ b/src/com/android/server/telecom/CallAudioManager.java
@@ -232,8 +232,10 @@ public class CallAudioManager extends CallsManagerListenerBase {
}
}
- // Turn off mute when a new incoming call is answered.
- mute(false /* shouldMute */);
+ // Turn off mute when a new incoming call is answered iff it's not a handover.
+ if (!call.isHandoverInProgress()) {
+ mute(false /* shouldMute */);
+ }
maybeStopRingingAndCallWaitingForAnsweredOrRejectedCall(call);
}